@@ -11,7 +11,7 @@ use warnings;
 use vars qw ( @ISA @EXPORT @EXPORT_OK $VERSION );
 use Exporter;
 
-$VERSION   = "2.08";
+$VERSION   = "2.09";
 @ISA       = qw ( Exporter );
 @EXPORT    = qw ();
 @EXPORT_OK = qw ();
@@ -698,6 +698,9 @@ L<Fred::Fish::DBUG::SignalKilller> - Allows you to implement action
 DBUG_SIG_ACTION_LOG for B<die>.  Really dangerous to use.  Will break most
 code bases.
 
+L<Fred::Fish::DBUG::Test> - A L<Test::More> wrapper to redirect test results to
+B<fish>.
+
 =cut
 
 # ==============================================================
